Starting from a matrix of coverages, the corresponding matrix of copy numbers is calculated.
The caluculation includes a sample normalization step and a amplicon normalization step.
Usage
calculate.CN(coverage, scale.amplicon=NULL)
Arguments
coverage
A numeric matrix containing the coverages of each amplicon (rows) in each sample (columns).
scale.amplicon
Method for amplicon normalization. If NULL the scaling factors are estimated from coverage.
Value
Matrix of copy numbers with the amplicon scaling factors ("scale.amplicon") as attribute.